@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import argparse
+import base64
 import logging
 import os
 import sys
@@ -46,7 +47,9 @@ from sigstore._verify import (
     CertificateVerificationFailure,
     RekorEntryMissing,
     VerificationFailure,
+    VerificationMaterials,
     Verifier,
+    policy,
 )
 
 logger = logging.getLogger(__name__)
@@ -272,23 +275,19 @@ def _parser() -> argparse.ArgumentParser:
     )
 
     verification_options = verify.add_argument_group("Extended verification options")
-
-    # NOTE: `--cert-email` and `--cert-identity` are mutually exclusive, until
-    # `--cert-email` is removed entirely.
-    cert_identity_options = verification_options.add_mutually_exclusive_group()
-    cert_identity_options.add_argument(
+    verification_options.add_argument(
+        "--cert-email",
+        metavar="EMAIL",
+        type=str,
+        help="Deprecated; causes an error. Use --cert-identity instead",
+    )
+    verification_options.add_argument(
         "--cert-identity",
         metavar="IDENTITY",
         type=str,
         default=os.getenv("SIGSTORE_CERT_IDENTITY"),
         help="The identity to check for in the certificate's Subject Alternative Name",
-    )
-    cert_identity_options.add_argument(
-        "--cert-email",
-        metavar="EMAIL",
-        type=str,
-        default=os.getenv("SIGSTORE_CERT_EMAIL"),
-        help="The email address to check for in the certificate's Subject Alternative Name",
+        required=True,
     )
     verification_options.add_argument(
         "--cert-oidc-issuer",
@@ -296,6 +295,7 @@ def _parser() -> argparse.ArgumentParser:
         type=str,
         default=os.getenv("SIGSTORE_CERT_OIDC_ISSUER"),
         help="The OIDC issuer URL to check for in the certificate's OIDC issuer extension",
+        required=True,
     )
     verification_options.add_argument(
         "--require-rekor-offline",
@@ -467,6 +467,15 @@ def _sign(args: argparse.Namespace) -> None:
 
 
 def _verify(args: argparse.Namespace) -> None:
+    # `--cert-email` has been functionally removed, but we check for it
+    # explicitly to provide a nicer error message than just a missing
+    # option.
+    if args.cert_email:
+        args._parser.error(
+            "--cert-email is a disabled alias for --cert-identity; "
+            "use --cert-identity instead"
+        )
+
     # `--rekor-bundle` is a temporary option, pending stabilization of the
     # Sigstore bundle format.
     if args.rekor_bundle:
@@ -475,14 +484,6 @@ def _verify(args: argparse.Namespace) -> None:
             "upcoming release of sigstore-python in favor of Sigstore-style bundles"
         )
 
-    # `--cert-email` is a deprecated alias for `--cert-identity`.
-    if args.cert_email and not args.cert_identity:
-        logger.warning(
-            "--cert-email is a deprecated alias for --cert-identity, and will be removed "
-            "in an upcoming release of sigstore-python"
-        )
-        args.cert_identity = args.cert_email
-
     # The presence of --rekor-bundle implies --require-rekor-offline.
     args.require_rekor_offline = args.require_rekor_offline or args.rekor_bundle
 
@@ -544,11 +545,11 @@ def _verify(args: argparse.Namespace) -> None:
     for file, inputs in input_map.items():
         # Load the signing certificate
         logger.debug(f"Using certificate from: {inputs['cert']}")
-        certificate = inputs["cert"].read_bytes().rstrip()
+        cert_pem = inputs["cert"].read_text()
 
         # Load the signature
         logger.debug(f"Using signature from: {inputs['sig']}")
-        signature = inputs["sig"].read_bytes().rstrip()
+        b64_signature = inputs["sig"].read_text()
 
         entry: Optional[RekorEntry] = None
         if inputs["bundle"].is_file():
@@ -558,15 +559,23 @@ def _verify(args: argparse.Namespace) -> None:
 
         logger.debug(f"Verifying contents from: {file}")
 
-        result = verifier.verify(
+        materials = VerificationMaterials(
             input_=file.read_bytes(),
-            certificate=certificate,
-            signature=signature,
-            expected_cert_identity=args.cert_identity,
-            expected_cert_oidc_issuer=args.cert_oidc_issuer,
+            cert_pem=cert_pem,
+            signature=base64.b64decode(b64_signature),
             offline_rekor_entry=entry,
         )
 
+        policy_ = policy.Identity(
+            identity=args.cert_identity,
+            issuer=args.cert_oidc_issuer,
+        )
+
+        result = verifier.verify(
+            materials=materials,
+            policy=policy_,
+        )
+
         if result:
             print(f"OK: {file}")
         else:
@@ -621,7 +630,7 @@ def _verify(args: argparse.Namespace) -> None:
 
                         Signature: {result.signature}
 
-                        Artifact hash: {result.sha256_artifact_hash}
+                        Artifact hash: {result.artifact_hash}
                         """
                     ),
                     file=sys.stderr,
