@@ -249,7 +249,7 @@ def get_identity_token(client_id: str, client_secret: str, issuer: Issuer) -> st
         client_id,
         client_secret,
     )
-    logging.debug(f"PAYLOAD: data={data}, auth={auth}")
+    logging.debug(f"PAYLOAD: data={data}")
     resp: requests.Response = requests.post(
         issuer.token_endpoint,
         data=data,
